<?php

namespace Drupal\druhels;

use DateTime;
use Drupal\Core\Datetime\DrupalDateTime;

class CommonHelper {

  /**
   * Return days count between two dates.
   *
   * @param string|integer|DrupalDateTime|DateTime $date_start
   * @param string|integer|DrupalDateTime|DateTime $date_end
   *
   * @return integer
   */
  public static function getDaysBetweenDates($date_start, $date_end) {
    if (is_int($date_start)) {
      $date_start = new \DateTime("@$date_start");
    }
    elseif (is_string($date_start)) {
      $date_start = new \DateTime($date_start);
    }
    elseif ($date_start instanceof DrupalDateTime) {
      $date_start = $date_start->getPhpDateTime();
    }
    if (!($date_start instanceof \DateTimeInterface)) {
      return NULL;
    }

    if (is_int($date_end)) {
      $date_end = new \DateTime("@$date_end");
    }
    elseif (is_string($date_end)) {
      $date_end = new \DateTime($date_end);
    }
    elseif ($date_end instanceof DrupalDateTime) {
      $date_end = $date_end->getPhpDateTime();
    }
    elseif (!($date_end instanceof \DateTimeInterface)) {
      return NULL;
    }

    return $date_end->diff($date_start)->format('%a');
  }

  /**
   * Return timestamp by date.
   *
   * @param int|string|DrupalDateTime|DateTime $date
   *
   * @return int|null
   */
  public static function getDateTimestamp($date) {
    if (is_int($date)) {
      return $date;
    }
    if (is_string($date)) {
      return strtotime($date);
    }
    if ($date instanceof DrupalDateTime || $date instanceof \DateTime) {
      return $date->getTimestamp();
    }
    return NULL;
  }

  /**
   * Return TRUE if $date_to_check is between $date_start and $date_end.
   *
   * @param string|integer|DrupalDateTime|DateTime $date_to_check
   * @param string|integer|DrupalDateTime|DateTime $date_start
   * @param string|integer|DrupalDateTime|DateTime $date_end
   *
   * @return boolean
   */
  public static function checkDateInDaterange($date_to_check, $date_start, $date_end) {
    $date_to_check = self::getDateTimestamp($date_to_check);
    $date_start = self::getDateTimestamp($date_start);
    $date_end = self::getDateTimestamp($date_end);

    if ($date_start === NULL) {
      $date_start = 0;
    }
    if ($date_end === NULL) {
      $date_end = PHP_INT_MAX;
    }

    return ($date_to_check >= $date_start && $date_to_check <= $date_end);
  }

}
