<?php

namespace Drupal\druhels;

use Drupal\file\Entity\File;
use Drupal\file\FileInterface;
use Drupal\file\FileStorageInterface;
use Drupal\image\Entity\ImageStyle;

class FileHelper {

  /**
   * Return file entity object by file uri.
   *
   * @return FileInterface|null
   */
  public static function getFileEntityByUri($uri) {
    $file_entity_storage = self::getFileStorage();
    if ($file_entities = $file_entity_storage->loadByProperties(['uri' => $uri])) {
      return current($file_entities);
    }
  }

  /**
   * Create file entity if not exists.
   *
   * @return FileInterface
   */
  public static function createFileEntityByUri($uri, $properties = [], $save = TRUE) {
    $file = self::getFileEntityByUri($uri);

    if (!$file) {
      $file = File::create([
        'uri' => $uri,
        'filename' => basename($uri),
      ] + $properties);

      if ($save) {
        $file->save();
      }
    }

    return $file;
  }

  /**
   * Return file extension without dot.
   *
   * @return string;
   */
  public static function getFileExtension($filename) {
    return pathinfo($filename, PATHINFO_EXTENSION);
  }

  /**
   * Return image style url.
   *
   * @param string $image_path The path or URI to the original image.
   * @param string $style_name Style name.
   *
   * @return string
   */
  public static function getImageStyleUrl($image_path, $style_name, $absolute_url = FALSE) {
    if ($style_name && ($image_style = ImageStyle::load($style_name))) {
      $image_style_url = $image_style->buildUrl($image_path);
      return $absolute_url ? $image_style_url : file_url_transform_relative($image_style_url);
    }

    return file_url_transform_relative(file_create_url($image_path));
  }

  /**
   * Return file storage.
   *
   * @return FileStorageInterface
   */
  public static function getFileStorage() {
    return \Drupal::entityTypeManager()->getStorage('file');
  }

}
