<?php

namespace Drupal\druhels;

use Drupal\node\Entity\Node;
use Drupal\node\NodeInterface;
use Drupal\node\NodeStorageInterface;
use Drupal\node\NodeViewBuilder;

class NodeHelper {

  /**
   * Return TRUE if current page is a node page.
   *
   * @return bool
   */
  public static function isNodePage($node_type = NULL) {
    static $current_node_type;

    if ($current_node_type === NULL) {
      if (DrupalHelper::getCurrentRouteName() == 'entity.node.canonical') {
        $current_node_type = self::getCurrentNode()->bundle();
      }
      else {
        $current_node_type = FALSE;
      }
    }

    return $node_type ? ($current_node_type == $node_type) : (bool)$current_node_type;
  }

  /**
   * Return current node in node page.
   *
   * @return NodeInterface|NULL
   */
  public static function getCurrentNode() {
    $node = \Drupal::routeMatch()->getParameter('node');

    if ($node && is_numeric($node)) {
      $node = Node::load($node);
    }

    return $node;
  }

  /**
   * Return node build array.
   *
   * @param NodeInterface|integer $node - Node object or nid.
   *
   * @return array Node render array.
   */
  public static function view($node, $view_mode = 'full') {
    if (is_numeric($node)) {
      $node = Node::load($node);
    }
    $node_view_builder = \Drupal::entityTypeManager()->getViewBuilder('node'); /** @var NodeViewBuilder $node_view_builder */

    return $node_view_builder->view($node, $view_mode);
  }

  /**
   * Return node storage.
   *
   * @return NodeStorageInterface
   */
  public static function getNodeStorage() {
    return \Drupal::entityTypeManager()->getStorage('node');
  }

}
