<?php

namespace Drupal\druhels;

use Drupal\Component\Utility\Html;

class SeoHelper {

  /**
   * Attach metatag to render array.
   *
   * @return null
   */
  public static function attachMetatag(&$build, $attachment_name, $meta_name, $content) {
    self::attachHtmlHead($build, $attachment_name, 'meta', [
      'name' => $meta_name,
      'content' => ['#plain_text' => $content],
    ]);
  }

  /**
   * Attach html_head tag.
   *
   * @return null
   */
  public static function attachHtmlHead(&$build, $attachment_name, $tag_name, $attributes) {
    $tag = [
      '#tag' => $tag_name,
      '#attributes' => $attributes,
    ];
    $build['#attached']['html_head'][] = [$tag, $attachment_name];
  }

  /**
   * Attach JSON-LD to render array.
   *
   * @return null
   */
  public static function attachJsonld(&$build, $name, $value, $weight = 1000) {
    $value = ArrayHelper::removeEmptyElements($value, TRUE);

    $element = [
      '#tag' => 'script',
      '#attributes' => [
        'type' => 'application/ld+json',
      ],
      '#value' => json_encode($value, JSON_UNESCAPED_UNICODE),
      '#weight' => $weight,
    ];

    $build['#attached']['html_head'][] = [$element, 'jsonld_' . $name];
  }

  /**
   * Render schema.org data.
   *
   * @return string
   */
  public static function renderSchemaorgData(array $data) {
    $output = '';

    foreach ($data as $name => $content) {
      if (strpos($name, '#') !== 0) {
        // Nested
        if (is_array($content) && isset($content['#itemtype'])) {
          $output .= "
            <div itemprop=\"$name\" itemscope itemtype=\"http://schema.org/{$content['#itemtype']}\">
              " . self::renderSchemaorgData($content) . "
            </div>
          ";
        }
        // Custom tag
        elseif (is_array($content)) {
          $attributes = [];
          foreach ($content as $attribute_name => $attribute_value) {
            if ($attribute_name != '#tag') {
              $attributes[] = substr($attribute_name, 1) . '="' . Html::escape($attribute_value) . '"';
            }
          }

          $tag = $content['#tag'] ?? 'meta';
          $output .= '<' . $tag . ' itemprop="' . $name . '" ' . implode(' ', $attributes) . ' />' . "\n";
        }
        // Meta
        else {
          $output .= '<meta itemprop="' . $name . '" content="' . Html::escape($content) . '" />' . "\n";
        }
      }
    }

    return $output;
  }

}
